@@ -36,13 +36,54 @@ function paraselene_receive(ps){
 	}
 }
 
+function paraselene_get_http(){
+	var obj=null;
+	if(window.ActiveXObject){
+		try{
+			obj=new ActiveXObject('Msxml2.XMLHTTP');
+		}catch(e){
+			obj=new ActiveXObject('Microsoft.XMLHTTP');
+		}
+	}else if(window.XMLHttpRequest){
+		obj=new XMLHttpRequest();
+	}
+	if(obj==null)return null;
+	return obj;
+}
+
+function paraselene_send(o){
+	var url='';
+	var data='';
+	if(o.tagName=='A'){
+		var x=o.getAttribute('href').split('?');
+		url=x[0];
+		if(x[1]){
+			data=x[1];
+		}
+	}
+	else if(o.tagName=='FORM'){
+		url=o.getAttribute('action');
+	}
+	else return true;
+
+	var url_test=url.split(':');
+	if(!url_test[1])	return true;
+	url_test=url.split('/');
+	if(!url_test[1])	return true;
+	url_test=url.split('.');
+	if(url_test[url_test.length-1]!='na')	return true;
+
+	var svr=paraselene_get_http();
+	if(svr==null)return true;
+	ho.open('POST',url,false);
+	ho.setRequestHeader('Content-Type','application/x-www-form-urlencoded');
+	ho.send(data);
+	return false;
+}
+
 ParaseleneAjax.prototype={
 	http_access:function(){
-		if(window.ActiveXObject){
-			this.http=new ActiveXObject('Microsoft.XMLHTTP');
-		}else if(window.XMLHttpRequest){
-			this.http=new XMLHttpRequest();
-		}
+		this.http=paraselene_get_http();
 		if(this.http==null)	return;
 		this.http.onreadystatechange=function(){
 			var p=arguments[0];
@@ -51,7 +92,7 @@ ParaseleneAjax.prototype={
 			};
 		}(paraselene_holder[this.no]);
 		this.http.open('GET','paraselene.json.na?key='+this.key,true);
-		this.http.send(null);
+		this.http.send('');
 	}
 };
 
