@@ -152,7 +152,7 @@ public abstract class SuperPage extends Page {
 	 * @param req リクエスト内容。
 	 * @exception PageException 処理の継続が不可能(ブラウザには500を返す)。
 	 */
-	public void firstOutput( RequestParameter req ) throws PageException {
+	public final void firstOutput( RequestParameter req ) throws PageException {
 		// 共通処理等あれば記述して下さい。
 		firstOutputMain( req );
 	}
