@@ -13,8 +13,13 @@ private static final long serialVersionUID = 1L;
  */
 public #4() {
 super();
+try {
 setInitialized( true );
 }
+catch( Exception e ) {
+Option.debug( e );
+}
+}
 /**
  * ページIDの取得。
  * @return ページID。#1.base.PageType.#6。
