@@ -12,6 +12,7 @@ import java.io.*;
 import java.net.*;
 import javax.servlet.http.*;
 import paraselene.tag.*;
+import paraselene.css.*;
 import paraselene.supervisor.*;
 import paraselene.tag.form.*;
 
@@ -216,8 +217,12 @@ public abstract class Page implements Serializable {
 	 * 初期化された事をマークします。
 	 * @param flag true:初期化済み、false:変更された。
 	 */
-	public void setInitialized( boolean flag ) {
+	public void setInitialized( boolean flag ) throws PageException {
 		init_f = flag;
+		if ( flag && beginning_called ) {
+			beginning_called = false;
+			beginning( now_req );
+		}
 	}
 
 	/**
@@ -270,7 +275,7 @@ public abstract class Page implements Serializable {
 		return list;
 	}
 
-	private Control[]	modified = new Control[0];
+	private transient Control[]	modified = new Control[0];
 
 	/**
 	 * ブラウザで変更が加えられたコントロールの取得。
@@ -326,7 +331,14 @@ public abstract class Page implements Serializable {
 			list.addAll( form.get( i ).reflect( req ) );
 		}
 		modified = list.toArray( new Control[0] );
-		if ( modified.length > 0 )	setInitialized( false );
+		if ( modified.length > 0 ) {
+			try {
+				setInitialized( false );
+			}
+			catch( PageException e ) {
+				Option.debug( e );
+			}
+		}
 	}
 
 	/**
@@ -334,6 +346,7 @@ public abstract class Page implements Serializable {
 	 * @return 押下ボタン。無ければnull。
 	 */
 	public synchronized Button getClickedButton() {
+		if ( getMainTag() == null )	return null;
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
 		int	size = form.size();
 		for ( int i = 0; i < size; i++ ) {
@@ -542,7 +555,7 @@ public abstract class Page implements Serializable {
 	 * ユニークキー。
 	 * @return ユニークキー。
 	 */
-	public String getUniKey() {
+	public String getUniqueKey() {
 		return Integer.toString( super.hashCode() );
 	}
 
@@ -634,7 +647,8 @@ public abstract class Page implements Serializable {
 	 * @param tag 検証対象。
 	 */
 	public synchronized void nameTag( Tag tag ) {
-		tag.setPage( this );
+		if ( getMainTag() == null )	return;
+		tag.setAssignedPage( this );
 		String	name = tag.getNameAttribute();
 		if ( name != null ) {
 			if ( Form.FORM_ID.equals( name ) )	return;
@@ -646,7 +660,6 @@ public abstract class Page implements Serializable {
 			if ( part instanceof Tag ) {
 				nameTag( (Tag)part );
 			}
-			else	part.setPage( this );
 		}
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
 		cnt = form.size();
@@ -663,6 +676,7 @@ public abstract class Page implements Serializable {
 	 * @param tag 除去対象。
 	 */
 	public synchronized void removeNameEntry( Tag tag ) {
+		if ( getMainTag() == null )	return;
 		ArrayList<Form>	form = getForm( getMainTag(), new ArrayList<Form>() );
 		int cnt = form.size();
 		for ( int i = 0; i < cnt; i++ ) {
@@ -677,12 +691,11 @@ public abstract class Page implements Serializable {
 			if ( part instanceof Tag ) {
 				removeNameEntry( (Tag)part );
 			}
-			else	part.setPage( null );
 		}
+		tag.setAssignedPage( null );
 		String	name = tag.getNameAttribute();
 		if ( name == null )	return;
 		clearDic( name );
-		tag.setPage( null );
 	}
 
 	/**
@@ -702,6 +715,17 @@ public abstract class Page implements Serializable {
 		return contents;
 	}
 
+	/**
+	 * 内容の移動。&lt;html&gt;配下全ての要素を this に上書きします。
+	 * this の元の内容は失われます。src は空になります。
+	 * @param src 元のページ。
+	 */
+	public void moveMainTag( Page src ) {
+		Tag	tag = src.getMainTag();
+		src.setMainTag( null );
+		setMainTag( tag );
+	}
+
 	/**
 	 * タグの取得。AやTABLEのような、タグの種別で探します。
 	 * 再帰的に探し、最初に見つかったインスタンスを返します。
@@ -721,8 +745,9 @@ public abstract class Page implements Serializable {
 	 * ただし、nameがnullなら、nullを返す。
 	 */
 	public Tag[] getAllTagByType( String name ) {
+		if ( getMainTag() == null )	return new Tag[0];
 		Tag	tag = getMainTag();
-		if ( tag == null )	return null;
+		if ( tag == null )	return new Tag[0];
 		return tag.getAllTagByType( name );
 	}
 
@@ -742,6 +767,7 @@ public abstract class Page implements Serializable {
 	 * @param copy_f true:内容をコピーする、false:内容のコピーは行わない。
 	 */
 	public synchronized void replaceTag( Tag from, Tag to, boolean copy_f ) {
+		if ( getMainTag() == null )	return;
 		Tag	tag = getMainTag().getDirectInnerTag( from );
 		int	idx = tag.indexOf( from );
 		tag.removeHTMLPart( from );
@@ -897,30 +923,97 @@ public abstract class Page implements Serializable {
 	public void beginning( RequestParameter req ) throws PageException {
 		if ( beginning_called )	return;
 		beginning_called = true;
-		Tag	head = getFirstTagByType( "head" );
-		if ( head != null ) {
-			int	idx = 0;
-			int	max = head.getHTMLPartCount();
-			for ( ; idx < max; idx++ ) {
-				HTMLPart	part = head.getHTMLPart( idx );
-				if ( !(part instanceof Tag) )	continue;
-				Tag	tag = (Tag)part;
-				if ( "link".equals( tag.getName() ) )	break;
-			}
-			try {
-				Tag	tag = new Tag( "link", true );
-				tag.setAttribute(
-					new Attribute( "rel", new Text( "stylesheet" ) ),
-					new Attribute( "href", new URIValue( "paraselene.css.na" ) ),
-					new Attribute( "type", new Text( "text/css" ) )
-				);
-				head.addHTMLPart( idx, tag );
-			}
-			catch( Exception e ){
-				Option.debug( e );
-			}
-		}
+		if ( getMainTag() == null )	return;
 		firstOutput( req );
+		ajax_f = true;
+		if ( getAccessedMobile() == RequestParameter.Mobile.NO_MOBILE && getAccessedSearchEngine() == RequestParameter.SearchEngine.NO_SEARCHENGINE ) {
+			AjaxSupport	ajax = getAjaxSupport();
+			Tag	head = getFirstTagByType( "head" );
+			Tag	body = getFirstTagByType( "body" );
+			if ( head != null ) {
+				int	idx = 0;
+				int	max = head.getHTMLPartCount();
+				for ( ; idx < max; idx++ ) {
+					HTMLPart	part = head.getHTMLPart( idx );
+					if ( !(part instanceof Tag) )	continue;
+					Tag	tag = (Tag)part;
+					if ( "link".equals( tag.getName() ) )	break;
+				}
+				try {
+					Tag	tag = new Tag( "link", true );
+					tag.setAttribute(
+						new Attribute( "rel", new Text( "stylesheet" ) ),
+						new Attribute( "href", new URIValue( "paraselene.css.na" ) ),
+						new Attribute( "type", new Text( "text/css" ) )
+					);
+					head.addHTMLPart( idx, tag );
+				}
+				catch( Exception e ){
+					Option.debug( e );
+				}
+			}
+			else	ajax_f = false;
+			if ( body != null && ajax != AjaxSupport.NO ) {
+				Tag	iframe = new Tag( "iframe", false );
+				iframe.setAttribute(
+					new Attribute( "id", AJAX_TARGET_ID ),
+					new Attribute( "height", new NumberValue( 1 ) ),
+					new Attribute( "width", new NumberValue( 1 ) ),
+					new Attribute( "scrolling", new Text( "no" ) ),
+					new Attribute( "style",
+						new Style(
+							new Property( "position", new Text( "absolute" ) ),
+							new Property( "top", new NumberValue( -100 ) ),
+							new Property( "left", new NumberValue( -100 ) ),
+							new Property( "overflow", new Text( "hidden" ) ),
+							new Property( "visibility", new Text( "hidden" ) )
+						)
+					)
+				);
+				Tag	unique = new Tag( "script", false );
+				unique.addHTMLPart( new PlainText( String.format( "var page_id=%s", getUniqueKey() ) ) );
+				body.addHTMLPart( iframe, unique );
+			}
+			else	ajax_f = false;
+		}
+		else	ajax_f = false;
+	}
+
+	public static final String	AJAX_TARGET_ID = "paraselene$Dragon'sTail";
+	private boolean ajax_f = false;
+	private transient RequestParameter	now_req;
+	private transient RequestParameter.Mobile			access_mobile;
+	private transient RequestParameter.SearchEngine	access_se;
+
+	/**
+	 * フレームワークが使用します。
+	 */
+	public boolean isAjax() { return ajax_f; }
+	
+	/**
+	 * フレームワークが使用します。
+	 */
+	public void setRequestParameter( RequestParameter req ) {
+		now_req = req;
+		if ( req != null ) {
+			access_mobile = req.judgeMobile();
+			access_se = req.judgeSearchEngine();
+		}
+	}
+
+	/**
+	 * RequestParameterから得られたRequestParameter.Mobileを返します。
+	 * @return 携帯判定結果。
+	 */
+	public RequestParameter.Mobile getAccessedMobile() {
+		return access_mobile;
+	}
+	/**
+	 * RequestParameterから得られたRequestParameter.SearchEngineを返します。
+	 * @return 検索エンジン判定結果。
+	 */
+	public RequestParameter.SearchEngine getAccessedSearchEngine() {
+		return access_se;
 	}
 }
 
