@@ -204,10 +204,8 @@ public class Text extends PlainText implements AttributeValuable, CSSValuable {
 							}
 						}
 						String	br = "<br>";
-						if ( embed != null ) {
-							if ( embed.isXML() ) {
-								br = "<br />";
-							}
+						if ( getAssignedTag().getAssignedPage().isXML() ) {
+							br = "<br />";
 						}
 						buf = buf.append( br );
 						continue;
