@@ -9,6 +9,7 @@ package paraselene.css;
 import java.io.*;
 import java.util.*;
 import paraselene.*;
+import paraselene.tag.*;
 import paraselene.mockup.*;
 
 
@@ -24,14 +25,15 @@ public class Property implements Serializable {
 	private String	name;
 	private CSSValuable[]	value;
 	private boolean	important_f;
-	private Page	embed;
+	private Tag	embed_tag = HTMLPart.getDummyTag();
 
-	void setPage( Page p ) {
-		embed = p;
+	void setAssignedTag( Tag t ) {
+		if ( t == null )	t = HTMLPart.getDummyTag();
+		embed_tag = t;
 		synchronized( this ) {
 			if ( value != null ) {
 				for ( int i = 0; i < value.length; i++ ) {
-					value[i].setPage( p );
+					value[i].setAssignedTag( t );
 				}
 			}
 		}
@@ -118,6 +120,7 @@ public class Property implements Serializable {
 	 */
 	public void setImportant( boolean important ) {
 		important_f = important;
+		embed_tag.setModify();
 	}
 
 	/**
@@ -134,6 +137,7 @@ public class Property implements Serializable {
 	 */
 	private void setName( String n ) {
 		name = n.toLowerCase( Locale.ENGLISH );
+		embed_tag.setModify();
 	}
 
 	/**
@@ -152,6 +156,7 @@ public class Property implements Serializable {
 	public void set( String v, String dec ) {
 		if ( v == null ) {
 			value = null;
+			embed_tag.setModify();
 			return;
 		}
 		String[]	str = CSSParser.split( CSSParser.split( v, ';' )[0], ' ' );
@@ -172,6 +177,7 @@ public class Property implements Serializable {
 			list.add( Converter.toCSSValuable( str[i], dec ) );
 		}
 		set( list.toArray( new CSSValuable[0] ) );
+		embed_tag.setModify();
 	}
 
 	/**
@@ -180,6 +186,7 @@ public class Property implements Serializable {
 	 */
 	public void set( Valuable ... v ) {
 		value = Converter.toCSSValuable( v );
+		embed_tag.setModify();
 	}
 
 	/**
