@@ -29,13 +29,13 @@ public class Style extends HTMLPart implements AttributeValuable {
 		setProperty( p );
 	}
 
-	public void setPage( Page p ) {
-		super.setPage( p );
+	public void setAssignedTag( Tag t ) {
+		super.setAssignedTag( t );
 		synchronized( this ) {
 			if ( prop == null )	return;
 			int cnt = prop.size();
 			for ( int i = 0; i < cnt; i++ ) {
-				prop.get( i ).setPage( p );
+				prop.get( i ).setAssignedTag( t );
 			}
 		}
 	}
@@ -69,25 +69,19 @@ public class Style extends HTMLPart implements AttributeValuable {
 		for ( int i = 0; i < s.length; i++ ) {
 			selector.add( s[i] );
 		}
+		getAssignedTag().setModify();
 	}
 
 	/**
 	 * 属性の設定。同じ属性があると上書きされます。
 	 * @param p 属性。
 	 */
-	public synchronized void setProperty( Property p ) {
-		prop.add( p );
-		prop.remove( map.put( p.getName(), p ) );
-	}
-
-	/**
-	 * 属性の設定。同じ属性があると上書きされます。
-	 * @param p 属性。
-	 */
-	public void setProperty( Property ... p ) {
+	public synchronized void setProperty( Property ... p ) {
 		for ( int i = 0; i < p.length; i++ ) {
-			setProperty( p[i] );
+			prop.add( p[i] );
+			prop.remove( map.put( p[i].getName(), p[i] ) );
 		}
+		getAssignedTag().setModify();
 	}
 
 	/**
@@ -96,6 +90,7 @@ public class Style extends HTMLPart implements AttributeValuable {
 	 */
 	public synchronized void removeProperty( String name ) {
 		prop.remove( map.remove( name ) );
+		getAssignedTag().setModify();
 	}
 
 	/**
