@@ -122,6 +122,7 @@ class SaxContainer {
 			buf = buf.append( data[i] );
 			last_part = null;
 		}
+/**
 		if ( "noframes".equals( name ) ) {
 			StringBuilder	sub = new StringBuilder( "<body name='body'>" );
 			sub = sub.append( buf );
@@ -141,12 +142,13 @@ class SaxContainer {
 				e.printStackTrace();
 			}
 		}
-		else {
+**/
+//		else {
 			String	str = buf.toString();
 			if ( crlf_f )	str = str.trim();
 			if ( str.isEmpty() )	return;
 			add( pp.makeText( str ) );
-		}
+//		}
 	}
 
 }
