@@ -25,6 +25,7 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			return Param.PACKAGE.get();
 		case 2:
 			buf = buf.append( "/**\n * Json\n */\nPARASELENE_JSON(-1),\n" );
+			buf = buf.append( "/**\n * Css\n */\nPARASELENE_CSS(-2),\n" );
 			for ( int i = 0; i < cnt; i++ ) {
 				PrePage	page = page_map.get( org_html.get( i ) );
 				buf = buf.append( "/**\n * " );
@@ -43,6 +44,12 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			buf = buf.append( "pf.addDefine(PARASELENE_JSON,page.getClass());\n");
 			buf = buf.append( "map.put(PARASELENE_JSON.id,PARASELENE_JSON);\n" );
 			buf = buf.append( "pf.returnPage(page);\n" );
+			buf = buf.append( "page=new " );
+			buf = buf.append( Param.PACKAGE.get() );
+			buf = buf.append( ".base.Css();\n" );
+			buf = buf.append( "pf.addDefine(PARASELENE_CSS,page.getClass());\n");
+			buf = buf.append( "map.put(PARASELENE_CSS.id,PARASELENE_CSS);\n" );
+			buf = buf.append( "pf.returnPage(page);\n" );
 			for ( int i = 0; i < cnt; i++ ) {
 				PrePage page = page_map.get( org_html.get( i ) );
 				buf = buf.append( "page=new " );
@@ -110,8 +117,9 @@ public class Linker extends paraselene.mockup.output.Readme implements OutputNo
 			new paraselene.mockup.output.source.base.PageLoader(),
 			new paraselene.mockup.output.source.base.PageType(),
 			new paraselene.mockup.output.source.base.Json(),
+			new paraselene.mockup.output.source.base.Css(),
 		};
-		String[]	name = { "PageLoader.java", "PageType.java", "Json.java" };
+		String[]	name = { "PageLoader.java", "PageType.java", "Json.java", "Css.java" };
 		for ( int i = 0; i < name.length; i++ ) {
 			if ( output[i] == null )	continue;
 			StringBuilder    out_path = new StringBuilder( Make.SRC_PATH );
