@@ -32,7 +32,7 @@ public class Make implements OutputNo {
 	static String escape( String s ) {
 		if ( s == null )	return "null";
 		char[]	ch = s.toCharArray();
-		StringBuffer	buf = new StringBuffer( "\"" );
+		StringBuilder	buf = new StringBuilder( "\"" );
 		for ( int i = 0; i < ch.length; i++ ) {
 			if ( ch[i] == '\n' ) {
 				buf = buf.append( "\\n" );
@@ -54,7 +54,7 @@ public class Make implements OutputNo {
 	private static final String EXCLUDE = "exclude";
 
 	private static void ex_copy( File ex ) throws IOException {
-		StringBuffer	out_path = new StringBuffer(
+		StringBuilder	out_path = new StringBuilder(
 			Param.OUT_PATH.get()
 		);
 		out_path = out_path.append( File.separator );
@@ -90,7 +90,7 @@ public class Make implements OutputNo {
 	throws FileNotFoundException, UnsupportedEncodingException, IOException,
 	DynamicPageException {
 		if ( !root.exists() ) {
-			System.err.println( root.getPath() + "is not found." );
+			System.err.println( root.getPath() + " is not found." );
 			System.exit( 1);
 		}
 		File[]	list = root.listFiles();
@@ -131,9 +131,7 @@ public class Make implements OutputNo {
 			new paraselene.mockup.output.source.DummyPage(),
 			new paraselene.mockup.output.source.Gate(),
 			new paraselene.mockup.output.source.SuperPage(),
-			Boolean.valueOf( Param.JSON.get() )?
-				new paraselene.mockup.output.source.Json():
-				null,
+			new paraselene.mockup.output.source.Json(),
 		};
 		String[]	name = {
 			"DummyPage.java", "Gate.java", "SuperPage.java", "Json.java"
@@ -141,7 +139,7 @@ public class Make implements OutputNo {
 		Make	mk = new Make();
 		for ( int i = 0; i < name.length; i++ ) {
 			if ( output[i] == null )	continue;
-			StringBuffer	buf = new StringBuffer( SRC_PATH );
+			StringBuilder	buf = new StringBuilder( SRC_PATH );
 			buf = buf.append( File.separator );
 			buf = buf.append( name[i] );
 			String	p_name = buf.toString();
@@ -181,7 +179,7 @@ public class Make implements OutputNo {
 		Param.setParam( argc );
 		Param.loadParam();
 
-		StringBuffer	buf = new StringBuffer( Param.OUT_PATH.get() );
+		StringBuilder	buf = new StringBuilder( Param.OUT_PATH.get() );
 		buf = buf.append( File.separator );
 		buf = buf.append( SRC_PATH );
 		String[]	part = Param.PACKAGE.get().split( "\\." );
@@ -193,15 +191,15 @@ public class Make implements OutputNo {
 
 		if ( Boolean.valueOf( Param.CLEAR.get() ) ) {
 			Linker.readme.echoln( "<DELETE PHASE>" );
-			buf = new StringBuffer( Param.OUT_PATH.get() );
+			buf = new StringBuilder( Param.OUT_PATH.get() );
 			buf = buf.append( File.separator );
 			buf = buf.append( EXCLUDE );
 			Output.rmdir( buf.toString() );
-			buf = new StringBuffer( SRC_PATH );
+			buf = new StringBuilder( SRC_PATH );
 			buf = buf.append( File.separator );
 			buf = buf.append( PrePage.out_dir[0] );
 			Output.rmdir( buf.toString() );
-			buf = new StringBuffer( SRC_PATH );
+			buf = new StringBuilder( SRC_PATH );
 			buf = buf.append( File.separator );
 			buf = buf.append( "base" );
 			Output.rmdir( buf.toString() );
