@@ -155,7 +155,7 @@ public enum Param {
 		"出力改行コードは、" + SOURCE_LINE.key + " の指定に従います。",
 		false, true ),
 	IGNORE_TAG_ACCESSER( "-ignore_tag_accesser",
-		"name があっても、get/setアクセッサを生成しないタグを指定します。\n" +
+		"name があっても、getアクセッサを生成しないタグを指定します。\n" +
 		"指定例) meta param",
 		false, false ),
 	PARAM_URI( "-uri_param_name",
