@@ -32,52 +32,52 @@ tag123.setAttribute(new Attribute("content",new Text("text/css")),new Attribute(
 tag121.addHTMLPart(tag123);
 Tag tag124=new Tag("title",false);
 tag124.setAttribute(new Attribute("name",new Text("title")));
-Text text155=new Text("Read me");
-tag124.addHTMLPart(text155);
+Text text156=new Text("Read me");
+tag124.addHTMLPart(text156);
 tag121.addHTMLPart(tag124);
 Tag tag125=new Tag("style",false);
 tag125.setAttribute(new Attribute("type",new Text("text/css")));
-Text text156=new Text("\n<!--\nth {\n		background-color: #cccccc;\ntext-align: left;\n}\n-->\n");
-tag125.addHTMLPart(text156);
+Text text157=new Text("\n<!--\ntable {\nborder: 1px solid  #000;\nborder-collapse : collapse ;\n}\nth {\nbackground-color: #cccccc;\ntext-align: left;\n}\n-->\n");
+tag125.addHTMLPart(text157);
 tag121.addHTMLPart(tag125);
 Tag tag126=new Tag("script",false);
 tag126.setAttribute(new Attribute("language",new Text("JavaScript")));
-Text text158=new Text("\n<!--\nfunction load( page ){\n	var top = document.uri_form.url.value;\n	if ( top == \"\" || document.uri_form.url.defaultValue == top ) {\n		alert( \"テキストボックスにURLを指定して下さい\" );\n		return;\n	}\n	if ( top.charAt( top.length -1 ) != \"/\" ) {\n		top = top + \"/\";\n	}\n	window.open( top + page, \"_blank\" );\n}\n-->\n");
-tag126.addHTMLPart(text158);
+Text text159=new Text("\n<!--\nfunction load( page ){\n	var top = document.uri_form.url.value;\n	if ( top == \"\" || document.uri_form.url.defaultValue == top ) {\n		alert( \"テキストボックスにURLを指定して下さい\" );\n		return;\n	}\n	if ( top.charAt( top.length -1 ) != \"/\" ) {\n		top = top + \"/\";\n	}\n	window.open( top + page, \"_blank\" );\n}\n-->\n");
+tag126.addHTMLPart(text159);
 tag121.addHTMLPart(tag126);
 tag120.addHTMLPart(tag121);
 Tag tag127=new Tag("body",false);
 Tag tag128=new Tag("div",false);
 tag128.setAttribute(new Attribute("name",new Text("echo")));
 tag127.addHTMLPart(tag128);
-Text text306=new Text("\n\n以下のファイルを生成しました。内容を確認して下さい。");
-tag127.addHTMLPart(text306);
+Text text308=new Text("\n\n以下のファイルを生成しました。内容を確認して下さい。");
+tag127.addHTMLPart(text308);
 Table tag131=new Table();
 tag131.setAttribute(new Attribute("border",new NumberValue("1")));
 Line tag133=new Line();
 Column tag134=new Column(Column.Type.DATA);
 tag134.setAttribute(new Attribute("name",new Text("root")));
-Text text160=new Text("<root>");
-tag134.addHTMLPart(text160);
+Text text161=new Text("<root>");
+tag134.addHTMLPart(text161);
 tag133.addHTMLPart(tag134);
 Column tag135=new Column(Column.Type.DATA);
 tag133.addHTMLPart(tag135);
 tag131.addHTMLPart(tag133);
 Line tag136=new Line();
 Column tag137=new Column(Column.Type.DATA);
-Text text163=new Text(" <exclude>");
-tag137.addHTMLPart(text163);
+Text text164=new Text(" <exclude>");
+tag137.addHTMLPart(text164);
 tag136.addHTMLPart(tag137);
 Column tag138=new Column(Column.Type.DATA);
-Text text167=new Text("除外されたファイルがコピーされています。\nこれらを、Webサーバー等の所定の場所に配置して下さい。\nこの中に存在するファイルの一覧は、後述の除外ファイル一覧を参照して下さい。");
-tag138.addHTMLPart(text167);
+Text text168=new Text("除外されたファイルがコピーされています。\nこれらを、Webサーバー等の所定の場所に配置して下さい。\nこの中に存在するファイルの一覧は、後述の除外ファイル一覧を参照して下さい。");
+tag138.addHTMLPart(text168);
 tag136.addHTMLPart(tag138);
 tag131.addHTMLPart(tag136);
 Line tag141=new Line();
 Column tag142=new Column(Column.Type.DATA);
 tag142.setAttribute(new Attribute("name",new Text("source")));
-Text text172=new Text(" <source>");
-tag142.addHTMLPart(text172);
+Text text173=new Text(" <source>");
+tag142.addHTMLPart(text173);
 tag141.addHTMLPart(tag142);
 Column tag143=new Column(Column.Type.DATA);
 tag141.addHTMLPart(tag143);
@@ -85,275 +85,275 @@ tag131.addHTMLPart(tag141);
 Line tag144=new Line();
 Column tag145=new Column(Column.Type.DATA);
 tag145.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
-Text text176=new Text("   <base>");
-tag145.addHTMLPart(text176);
+Text text177=new Text("   <base>");
+tag145.addHTMLPart(text177);
 tag144.addHTMLPart(tag145);
 Column tag146=new Column(Column.Type.DATA);
 tag146.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
 Tag tag147=new Tag("b",false);
-Text text182=new Text("この中のソースファイルは変更しないで下さい。");
-tag147.addHTMLPart(text182);
+Text text183=new Text("この中のソースファイルは変更しないで下さい。");
+tag147.addHTMLPart(text183);
 tag146.addHTMLPart(tag147);
 tag144.addHTMLPart(tag146);
 tag131.addHTMLPart(tag144);
 Line tag148=new Line();
 Column tag149=new Column(Column.Type.DATA);
-Text text183=new Text("   <logic>");
-tag149.addHTMLPart(text183);
+Text text184=new Text("   <logic>");
+tag149.addHTMLPart(text184);
 tag148.addHTMLPart(tag149);
 Column tag150=new Column(Column.Type.DATA);
-Text text189=new Text("ロジック記述のためのスケルトンソースファイルが格納されています。\n自由に変更可能ですが、");
-tag150.addHTMLPart(text189);
+Text text190=new Text("ロジック記述のためのスケルトンソースファイルが格納されています。\n自由に変更可能ですが、");
+tag150.addHTMLPart(text190);
 Tag tag152=new Tag("b",false);
-Text text191=new Text("クラス名は変更しないで下さい。");
-tag152.addHTMLPart(text191);
+Text text192=new Text("クラス名は変更しないで下さい。");
+tag152.addHTMLPart(text192);
 tag150.addHTMLPart(tag152);
-Text text194=new Text("\nこの中に存在するクラスの一覧は、後述のlogicクラス一覧を参照して下さい。");
-tag150.addHTMLPart(text194);
+Text text195=new Text("\nこの中に存在するクラスの一覧は、後述のlogicクラス一覧を参照して下さい。");
+tag150.addHTMLPart(text195);
 tag148.addHTMLPart(tag150);
 tag131.addHTMLPart(tag148);
 Line tag154=new Line();
 Column tag155=new Column(Column.Type.DATA);
 tag155.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
-Text text195=new Text("   <view>");
-tag155.addHTMLPart(text195);
+Text text196=new Text("   <view>");
+tag155.addHTMLPart(text196);
 tag154.addHTMLPart(tag155);
 Column tag156=new Column(Column.Type.DATA);
 tag156.setAttribute(new Attribute("bgcolor",new Color("#EEEEEE")));
 Tag tag157=new Tag("b",false);
-Text text201=new Text("この中のソースファイルは変更しないで下さい。");
-tag157.addHTMLPart(text201);
+Text text202=new Text("この中のソースファイルは変更しないで下さい。");
+tag157.addHTMLPart(text202);
 tag156.addHTMLPart(tag157);
 tag154.addHTMLPart(tag156);
 tag131.addHTMLPart(tag154);
 Line tag158=new Line();
 Column tag159=new Column(Column.Type.DATA);
-Text text202=new Text("   DummyPage.java");
-tag159.addHTMLPart(text202);
+Text text203=new Text("   DummyPage.java");
+tag159.addHTMLPart(text203);
 tag158.addHTMLPart(tag159);
 Column tag160=new Column(Column.Type.DATA);
-Text text205=new Text("NullPage派生クラスのスケルトンソースファイルです。\n自由に変更可能ですが、");
-tag160.addHTMLPart(text205);
+Text text206=new Text("NullPage派生クラスのスケルトンソースファイルです。\n自由に変更可能ですが、");
+tag160.addHTMLPart(text206);
 Tag tag162=new Tag("b",false);
-Text text207=new Text("クラス名は変更しないで下さい。");
-tag162.addHTMLPart(text207);
+Text text208=new Text("クラス名は変更しないで下さい。");
+tag162.addHTMLPart(text208);
 tag160.addHTMLPart(tag162);
 tag158.addHTMLPart(tag160);
 tag131.addHTMLPart(tag158);
 Line tag163=new Line();
 Column tag164=new Column(Column.Type.DATA);
-Text text209=new Text("   Gate.java");
-tag164.addHTMLPart(text209);
+Text text210=new Text("   Gate.java");
+tag164.addHTMLPart(text210);
 tag163.addHTMLPart(tag164);
 Column tag165=new Column(Column.Type.DATA);
-Text text212=new Text("サーブレット本体のスケルトンソースファイルです。\ndoGetやdoPostはスーパークラス側で実装されており、その動作は変更できません。\nそれ以外に関しては自由に変更可能ですが、");
-tag165.addHTMLPart(text212);
+Text text213=new Text("サーブレット本体のスケルトンソースファイルです。\ndoGetやdoPostはスーパークラス側で実装されており、その動作は変更できません。\nそれ以外に関しては自由に変更可能ですが、");
+tag165.addHTMLPart(text213);
 Tag tag168=new Tag("b",false);
-Text text215=new Text("クラス名は変更しないで下さい。");
-tag168.addHTMLPart(text215);
+Text text216=new Text("クラス名は変更しないで下さい。");
+tag168.addHTMLPart(text216);
 tag165.addHTMLPart(tag168);
 tag163.addHTMLPart(tag165);
 tag131.addHTMLPart(tag163);
 Line tag169=new Line();
 Column tag170=new Column(Column.Type.DATA);
-Text text218=new Text("   Json.java");
-tag170.addHTMLPart(text218);
+Text text219=new Text("   Json.java");
+tag170.addHTMLPart(text219);
 tag169.addHTMLPart(tag170);
 Column tag171=new Column(Column.Type.DATA);
-Text text221=new Text("非同期通信時に返す値をハンドリングするためのクラスです。\n自由に変更可能ですが、");
-tag171.addHTMLPart(text221);
+Text text222=new Text("非同期通信時に返す値をハンドリングするためのクラスです。\n自由に変更可能ですが、");
+tag171.addHTMLPart(text222);
 Tag tag173=new Tag("b",false);
-Text text223=new Text("クラス名は変更しないで下さい。");
-tag173.addHTMLPart(text223);
+Text text225=new Text("クラス名は変更しないで下さい。");
+tag173.addHTMLPart(text225);
 tag171.addHTMLPart(tag173);
 tag169.addHTMLPart(tag171);
 tag131.addHTMLPart(tag169);
 Line tag174=new Line();
 Column tag175=new Column(Column.Type.DATA);
-Text text225=new Text("   SuperPage.java");
-tag175.addHTMLPart(text225);
+Text text227=new Text("   SuperPage.java");
+tag175.addHTMLPart(text227);
 tag174.addHTMLPart(tag175);
 Column tag176=new Column(Column.Type.DATA);
-Text text228=new Text("動的ページのスーパークラスのスケルトンソースファイルです。\n全ページで共通となる処理や、ユーティリティ的なメソッドを記述できます。\n自由に変更可能ですが、");
-tag176.addHTMLPart(text228);
+Text text230=new Text("動的ページのスーパークラスのスケルトンソースファイルです。\n全ページで共通となる処理や、ユーティリティ的なメソッドを記述できます。\n自由に変更可能ですが、");
+tag176.addHTMLPart(text230);
 Tag tag179=new Tag("b",false);
-Text text231=new Text("クラス名は変更しないで下さい。");
-tag179.addHTMLPart(text231);
+Text text233=new Text("クラス名は変更しないで下さい。");
+tag179.addHTMLPart(text233);
 tag176.addHTMLPart(tag179);
 tag174.addHTMLPart(tag176);
 tag131.addHTMLPart(tag174);
 Line tag180=new Line();
 Column tag181=new Column(Column.Type.DATA);
-Text text234=new Text(" build.xml");
-tag181.addHTMLPart(text234);
+Text text236=new Text(" build.xml");
+tag181.addHTMLPart(text236);
 tag180.addHTMLPart(tag181);
 Column tag182=new Column(Column.Type.DATA);
-Tag tag183=new Tag("a",false);
+Anchor tag183=new Anchor();
 tag183.setAttribute(new Attribute("target",new Text("_blank")),new Attribute("href",new URIValue("http://www.jajakarta.org/ant/")));
-Text text235=new Text("Ant");
-tag183.addHTMLPart(text235);
+Text text237=new Text("Ant");
+tag183.addHTMLPart(text237);
 tag182.addHTMLPart(tag183);
-Text text236=new Text("のビルドファイルです。この場所で実行するとビルドを行います。\nただし、paraselene.jarにクラスパスを通しておいて下さい。\nまた、必要に応じて、このファイルを変更して使用して下さい。");
-tag182.addHTMLPart(text236);
+Text text238=new Text("のビルドファイルです。この場所で実行するとビルドを行います。\nただし、paraselene.jarにクラスパスを通しておいて下さい。\nまた、必要に応じて、このファイルを変更して使用して下さい。");
+tag182.addHTMLPart(text238);
 List tag186=new List(List.Type.UNORDERED);
 ListItem tag187=new ListItem(ListItem.Type.LIST_ITEM);
-Text text239=new Text("ant\n引数なしで実行するとソースをコンパイルします。\nこの階層に<classes>ディレクトリを作成し、クラスファイルが出力されます。");
-tag187.addHTMLPart(text239);
+Text text241=new Text("ant\n引数なしで実行するとソースをコンパイルします。\nこの階層に<classes>ディレクトリを作成し、クラスファイルが出力されます。");
+tag187.addHTMLPart(text241);
 tag186.addHTMLPart(tag187);
 ListItem tag190=new ListItem(ListItem.Type.LIST_ITEM);
-Text text248=new Text("ant doc\ndocを引数にするとjavadocを生成します。\nこの階層に<doc>ディレクトリを作成し、htmlファイルが出力されます。");
-tag190.addHTMLPart(text248);
+Text text250=new Text("ant doc\ndocを引数にするとjavadocを生成します。\nこの階層に<doc>ディレクトリを作成し、htmlファイルが出力されます。");
+tag190.addHTMLPart(text250);
 tag186.addHTMLPart(tag190);
 ListItem tag193=new ListItem(ListItem.Type.LIST_ITEM);
-Text text257=new Text("ant clean\ncleanを引数にすると、<classes>と<doc>ディレクトリを削除します。");
-tag193.addHTMLPart(text257);
+Text text259=new Text("ant clean\ncleanを引数にすると、<classes>と<doc>ディレクトリを削除します。");
+tag193.addHTMLPart(text259);
 tag186.addHTMLPart(tag193);
 tag182.addHTMLPart(tag186);
 tag180.addHTMLPart(tag182);
 tag131.addHTMLPart(tag180);
 Line tag195=new Line();
 Column tag196=new Column(Column.Type.DATA);
-Text text270=new Text(" web.xml");
-tag196.addHTMLPart(text270);
+Text text272=new Text(" web.xml");
+tag196.addHTMLPart(text272);
 tag195.addHTMLPart(tag196);
 Column tag197=new Column(Column.Type.DATA);
-Text text271=new Text("WEB-INF配下に配置するweb.xmlの雛形です。\nこれをそのまま、または必要箇所をコピーして使用して下さい。");
-tag197.addHTMLPart(text271);
+Text text273=new Text("WEB-INF配下に配置するweb.xmlの雛形です。\nこれをそのまま、または必要箇所をコピーして使用して下さい。");
+tag197.addHTMLPart(text273);
 tag195.addHTMLPart(tag197);
 tag131.addHTMLPart(tag195);
 tag127.addHTMLPart(tag131);
-Text text308=new Text("\n");
-tag127.addHTMLPart(text308);
+Text text310=new Text("\n");
+tag127.addHTMLPart(text310);
 Form tag200=new Form();
 tag200.setAttribute(new Attribute("name",new Text("uri_form")));
 SingleTextBox tag201=new SingleTextBox(false);
-tag201.setAttribute(new Attribute("style",new Style(Property.create("background-color :#FFFF00;","UTF-8"))),new Attribute("name",new Text("url")),new Attribute("value",new Text("http://")),new Attribute("type",new Text("text")),new Attribute("size",new NumberValue("60")));
+tag201.setAttribute(new Attribute("style",new Style(Property.create("background-color:#FFFF00;","UTF-8"))),new Attribute("name",new Text("url")),new Attribute("value",new Text("http://")),new Attribute("type",new Text("text")),new Attribute("size",new NumberValue("60")));
 tag200.addHTMLPart(tag201);
-Text text280=new Text("\n例えばここに、http://localhost:8080/test/ と予め入力しておき、logicクラス一覧の");
-tag200.addHTMLPart(text280);
+Text text282=new Text("\n例えばここに、http://localhost:8080/test/ と予め入力しておき、logicクラス一覧の");
+tag200.addHTMLPart(text282);
 Tag tag203=new Tag("span",false);
 tag203.setAttribute(new Attribute("name",new Text("ex")));
-Text text275=new Text("xxx");
-tag203.addHTMLPart(text275);
+Text text277=new Text("xxx");
+tag203.addHTMLPart(text277);
 tag200.addHTMLPart(tag203);
-Text text276=new Text(" のリンクをクリックすると\nhttp://loclhost:8080/test/");
-tag200.addHTMLPart(text276);
+Text text278=new Text(" のリンクをクリックすると\nhttp://loclhost:8080/test/");
+tag200.addHTMLPart(text278);
 Tag tag205=new Tag("span",false);
 tag205.setAttribute(new Attribute("name",new Text("ex")));
-Text text278=new Text("xxx");
-tag205.addHTMLPart(text278);
+Text text280=new Text("xxx");
+tag205.addHTMLPart(text280);
 tag200.addHTMLPart(tag205);
-Text text279=new Text(" が開きます。");
-tag200.addHTMLPart(text279);
+Text text281=new Text(" が開きます。");
+tag200.addHTMLPart(text281);
 tag127.addHTMLPart(tag200);
 Table tag206=new Table();
 tag206.setAttribute(new Attribute("name",new Text("class_list")),new Attribute("border",new NumberValue("1")));
 Tag tag207=new Tag("caption",false);
-Text text282=new Text("logicクラス一覧");
-tag207.addHTMLPart(text282);
+Text text284=new Text("logicクラス一覧");
+tag207.addHTMLPart(text284);
 tag206.addHTMLPart(tag207);
 Line tag209=new Line();
 Column tag210=new Column(Column.Type.HEADER);
-Text text283=new Text("No ");
-tag210.addHTMLPart(text283);
+Text text285=new Text("No ");
+tag210.addHTMLPart(text285);
 tag209.addHTMLPart(tag210);
 Column tag211=new Column(Column.Type.HEADER);
-Text text285=new Text("モックアップファイル名");
-tag211.addHTMLPart(text285);
+Text text287=new Text("モックアップファイル名");
+tag211.addHTMLPart(text287);
 tag209.addHTMLPart(tag211);
 Column tag212=new Column(Column.Type.HEADER);
-Text text286=new Text("ページタイトル");
-tag212.addHTMLPart(text286);
+Text text288=new Text("ページタイトル");
+tag212.addHTMLPart(text288);
 tag209.addHTMLPart(tag212);
 Column tag213=new Column(Column.Type.HEADER);
-Text text287=new Text("クラス名");
-tag213.addHTMLPart(text287);
+Text text289=new Text("クラス名");
+tag213.addHTMLPart(text289);
 tag209.addHTMLPart(tag213);
 Column tag214=new Column(Column.Type.HEADER);
-Text text288=new Text("PageID");
-tag214.addHTMLPart(text288);
+Text text290=new Text("PageID");
+tag214.addHTMLPart(text290);
 tag209.addHTMLPart(tag214);
 Column tag215=new Column(Column.Type.HEADER);
-Text text289=new Text("実行時URL\n※getAliasURI()が優先されます。");
-tag215.addHTMLPart(text289);
+Text text291=new Text("実行時URL\n※getAliasURI()が優先されます。");
+tag215.addHTMLPart(text291);
 tag209.addHTMLPart(tag215);
 Column tag217=new Column(Column.Type.HEADER);
-Text text292=new Text("特記");
-tag217.addHTMLPart(text292);
+Text text294=new Text("特記");
+tag217.addHTMLPart(text294);
 tag209.addHTMLPart(tag217);
 tag206.addHTMLPart(tag209);
 Line tag219=new Line();
 Column tag220=new Column(Column.Type.DATA);
 tag220.setAttribute(new Attribute("align",new Text("right")));
-Text text293=new Text("1");
-tag220.addHTMLPart(text293);
+Text text295=new Text("1");
+tag220.addHTMLPart(text295);
 tag219.addHTMLPart(tag220);
 Column tag221=new Column(Column.Type.DATA);
-Text text294=new Text("index.html");
-tag221.addHTMLPart(text294);
+Text text296=new Text("index.html");
+tag221.addHTMLPart(text296);
 tag219.addHTMLPart(tag221);
 Column tag222=new Column(Column.Type.DATA);
-Text text295=new Text("xxxx");
-tag222.addHTMLPart(text295);
+Text text297=new Text("xxxx");
+tag222.addHTMLPart(text297);
 tag219.addHTMLPart(tag222);
 Column tag223=new Column(Column.Type.DATA);
-Text text296=new Text("x.logic.x");
-tag223.addHTMLPart(text296);
+Text text298=new Text("x.logic.x");
+tag223.addHTMLPart(text298);
 tag219.addHTMLPart(tag223);
 Column tag224=new Column(Column.Type.DATA);
-Text text297=new Text("enum");
-tag224.addHTMLPart(text297);
+Text text299=new Text("enum");
+tag224.addHTMLPart(text299);
 tag219.addHTMLPart(tag224);
 Column tag225=new Column(Column.Type.DATA);
-Text text298=new Text("on.x.na");
-tag225.addHTMLPart(text298);
+Text text300=new Text("on.x.na");
+tag225.addHTMLPart(text300);
 tag219.addHTMLPart(tag225);
 Column tag226=new Column(Column.Type.DATA);
 tag219.addHTMLPart(tag226);
 tag206.addHTMLPart(tag219);
 tag127.addHTMLPart(tag206);
-Text text309=new Text("\n");
-tag127.addHTMLPart(text309);
+Text text311=new Text("\n");
+tag127.addHTMLPart(text311);
 Table tag228=new Table();
 tag228.setAttribute(new Attribute("name",new Text("ex_list")),new Attribute("border",new NumberValue("1")));
 Tag tag229=new Tag("caption",false);
-Text text299=new Text("除外ファイル一覧");
-tag229.addHTMLPart(text299);
+Text text301=new Text("除外ファイル一覧");
+tag229.addHTMLPart(text301);
 tag228.addHTMLPart(tag229);
 Line tag231=new Line();
 Column tag232=new Column(Column.Type.HEADER);
-Text text300=new Text("No");
-tag232.addHTMLPart(text300);
+Text text302=new Text("No");
+tag232.addHTMLPart(text302);
 tag231.addHTMLPart(tag232);
 Column tag233=new Column(Column.Type.HEADER);
-Text text301=new Text("モックアップファイル名");
-tag233.addHTMLPart(text301);
+Text text303=new Text("モックアップファイル名");
+tag233.addHTMLPart(text303);
 tag231.addHTMLPart(tag233);
 Column tag234=new Column(Column.Type.HEADER);
-Text text302=new Text("解決パス");
-tag234.addHTMLPart(text302);
+Text text304=new Text("解決パス");
+tag234.addHTMLPart(text304);
 tag231.addHTMLPart(tag234);
 tag228.addHTMLPart(tag231);
 Line tag236=new Line();
 Column tag237=new Column(Column.Type.DATA);
 tag237.setAttribute(new Attribute("align",new Text("right")));
-Text text303=new Text("1");
-tag237.addHTMLPart(text303);
+Text text305=new Text("1");
+tag237.addHTMLPart(text305);
 tag236.addHTMLPart(tag237);
 Column tag238=new Column(Column.Type.DATA);
-Text text304=new Text("index.html");
-tag238.addHTMLPart(text304);
+Text text306=new Text("index.html");
+tag238.addHTMLPart(text306);
 tag236.addHTMLPart(tag238);
 Column tag239=new Column(Column.Type.DATA);
-Text text305=new Text("index.html");
-tag239.addHTMLPart(text305);
+Text text307=new Text("index.html");
+tag239.addHTMLPart(text307);
 tag236.addHTMLPart(tag239);
 tag228.addHTMLPart(tag236);
 tag127.addHTMLPart(tag228);
 tag120.addHTMLPart(tag127);
 setMainTag(tag120);
 setDoctype(false,null);
-addVersionMeta("Paraselene 2.0.1 (http://paraselene.sourceforge.jp/)","Tue Nov 03 15:36:17 JST 2009");
+addVersionMeta("Paraselene 2.0.3 (http://paraselene.sourceforge.jp/)","Sun Nov 08 16:50:03 JST 2009");
 
 }
 catch(Exception e){}
@@ -436,7 +436,7 @@ return getAllTag( "root" );
 }
 /**
  * uri_form.
- * <br>&lt;form&nbsp;id=&quot;paraselene$id$4xdl0gyuiuem&quot;&nbsp;name=&quot;uri_form&quot;&gt;
+ * <br>&lt;form&nbsp;id=&quot;paraselene$id$87mmq3frsa1u&quot;&nbsp;name=&quot;uri_form&quot;&gt;
  **/
 public Form getUriFormForm() {
 return (Form)getTag( "uri_form" );
@@ -462,7 +462,7 @@ return getAllTag( "echo" );
 }
 /**
  * url.
- * <br>&lt;input&nbsp;style=&quot;background-color&nbsp;:#FFFF00;&quot;&nbsp;name=&quot;url&quot;&nbsp;value=&quot;http://&quot;&nbsp;type=&quot;text&quot;&nbsp;size=&quot;60&quot;&gt;
+ * <br>&lt;input&nbsp;style=&quot;background-color:#FFFF00;&quot;&nbsp;name=&quot;url&quot;&nbsp;value=&quot;http://&quot;&nbsp;type=&quot;text&quot;&nbsp;size=&quot;60&quot;&gt;
  **/
 public SingleTextBox getUrlInput() {
 return (SingleTextBox)getTag( "url" );
