@@ -68,6 +68,14 @@ public class Forward implements Serializable {
 		session_clear_f = session_off;
 	}
 
+	/**
+	 * コンストラクタ。ページへ遷移。new Forward( id, true, false )と等価です。
+	 * @param id 指定ページの出力。
+	 */
+	public Forward( PageID id ) {
+		this( id, true, false );
+	}
+
 	Page getPage( Page from ) {
 		if ( out_page == null )	return null;
 		if ( from != null ) {
