@@ -60,3 +60,9 @@ public abstract class NullPage extends Page {
 	public void firstOutput( RequestParameter req ) throws PageException{}
 }
 
+class NullPage4Alias extends NullPage {
+	public Forward input( RequestParameter req, Forward fw ) throws PageException {
+		return fw;
+	}
+}
+
