@@ -217,7 +217,7 @@ public abstract class Supervisor extends HttpServlet {
 		}
 		HttpSession	session = req.getSession( false );
 		if ( session != null ) {
-			session.invalidate();
+			clear_session( session );
 		}
 		return fw;
 	}
@@ -225,6 +225,11 @@ public abstract class Supervisor extends HttpServlet {
 		return onErrorDebug( e, req, res, 500 );
 	}
 
+	private static void clear_session( HttpSession s ) {
+//Thread.dumpStack();
+		s.invalidate();
+	}
+
 	/**
 	 * 不正呼び出しの検出通知。
 	 * @param ir 検出内容。
@@ -235,6 +240,8 @@ public abstract class Supervisor extends HttpServlet {
 	 */
 	public abstract Forward onIllegalRequest( IllegalRequest ir, RequestParameter req, Page from, Page to );
 
+	private static final Page	null4alias = new NullPage4Alias();
+
 	private void doAction( HttpServletRequest request, HttpServletResponse res ) {
 		HttpSession	session = null;
 		SessionData	data = null;
@@ -269,7 +276,7 @@ public abstract class Supervisor extends HttpServlet {
 				if ( TransactionSequencer.isMustSession( uri ) ) {
 					if ( holder.search_engine ) {
 						new Forward( 403 ).Action( this, res );
-						session.invalidate();
+						clear_session( session );
 						return;
 					}
 					if ( holder.session_null && path_data != null ) {
@@ -280,24 +287,27 @@ public abstract class Supervisor extends HttpServlet {
 							next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
-								if ( session_f )	if (session != null )	session.invalidate();
+								if ( session_f )	if (session != null )	clear_session( session );
 								return;
 							}
 						}
 					}
 				}
 			}
+			else {
+				path_data.from = null4alias;
+			}
 			if ( path_data == null ) {
 				fw = new Forward( 403 );
 				fw.Action( this, res );
-				if (session != null )	session.invalidate();
+				if (session != null )	clear_session( session );
 				return;
 			}
 			if ( path_data.redirect != null ) {
 				if ( !holder.data.write( this, path_data.redirect, holder ) ) {
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	session.invalidate();
+					if (session != null )	clear_session( session );
 				}
 				return;
 			}
@@ -308,7 +318,7 @@ public abstract class Supervisor extends HttpServlet {
 					System.out.println( "last page is null" );
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	session.invalidate();
+					if (session != null )	clear_session( session );
 					return;
 				}
 				if ( last_page.isAllowHistoryAdd() ) {
@@ -325,7 +335,7 @@ public abstract class Supervisor extends HttpServlet {
 							next_page = fw.getPage( null );
 							if ( next_page == null ) {
 								fw.Action( this, res );
-								if ( session_f )	if (session != null )	session.invalidate();
+								if ( session_f )	if (session != null )	clear_session( session );
 								return;
 							}
 						}
@@ -340,14 +350,14 @@ public abstract class Supervisor extends HttpServlet {
 					System.out.println( "next page is null" );
 					fw = new Forward( 403 );
 					fw.Action( this, res );
-					if (session != null )	session.invalidate();
+					if (session != null )	clear_session( session );
 					return;
 				}
 			}
 			else {
 				fw = new Forward( 403 );
 				fw.Action( this, res );
-				if (session != null )	session.invalidate();
+				if (session != null )	clear_session( session );
 				return;
 			}
 
@@ -359,7 +369,7 @@ public abstract class Supervisor extends HttpServlet {
 					next_page = fw.getPage( null );
 					if ( next_page == null ) {
 						fw.Action( this, res );
-						if ( session_f )	if (session != null )	session.invalidate();
+						if ( session_f )	if (session != null )	clear_session( session );
 						return;
 					}
 				}
@@ -369,15 +379,17 @@ public abstract class Supervisor extends HttpServlet {
 					fw = new Forward( next_page.getID(), true, false );
 					fact.returnPage( next_page );
 				}
+				last_page.setRequestParameter( req );
 				last_page.reflect( req );
 				fw = SandBox.input( last_page, req, fw );
 				last_page.setInitialized( false );
+				last_page.setRequestParameter( null );
 				holder.history_use = fw.history_f;
 				session_f = fw.session_clear_f;
 				next_page = fw.getPage( last_page );
 				if ( next_page == null ) {
 					fw.Action( this, res );
-					if ( session_f )	if (session != null )	session.invalidate();
+					if ( session_f )	if (session != null )	clear_session( session );
 					return;
 				}
 			}
@@ -403,7 +415,7 @@ public abstract class Supervisor extends HttpServlet {
 		}
 		if ( holder == null )	return old;
 		if ( old != null ) {
-			old.invalidate();
+			clear_session( old );
 		}
 		HttpSession	session = holder.req.getSession( true );
 		session.setAttribute( SESSION_DATA, holder.data );
@@ -425,7 +437,7 @@ public abstract class Supervisor extends HttpServlet {
 			session = null;
 		}
 		if ( session_f ) {
-			if ( session != null )	session.invalidate();
+			if ( session != null )	clear_session( session );
 			session = null;
 		}
 		else if ( session == null ) {
@@ -454,7 +466,7 @@ public abstract class Supervisor extends HttpServlet {
 						}
 					}
 					if ( buf == null ) {
-						RequestParameter.Mobile	mob = param.judgMobile();
+						RequestParameter.Mobile	mob = param.judgeMobile();
 						switch( mob ) {
 						case AU: case DOCOMO: case J_PHONE:
 							buf = new StringBuilder( XHTML );
@@ -484,7 +496,7 @@ public abstract class Supervisor extends HttpServlet {
 				res.addHeader( "Cache-Control", "public" );
 			}
 			else {
-				res.addHeader( "Cache-Control", "no-cache, no-store" );
+				//res.addHeader( "Cache-Control", "no-cache, no-store" );
 			}
 			if ( fw != null ) {
 				int	ck_cnt = fw.out_cookie.size();
@@ -622,9 +634,11 @@ public abstract class Supervisor extends HttpServlet {
 				}
 			}
 		}
+		next_page.setRequestParameter( holder.request );
 		Page	view = SandBox.output( next_page, last_page, holder.request );
 		if ( view == null )	view = next_page;
 		next_page.setInitialized( false );
+		next_page.setRequestParameter( null );
 		return new Page[]{ next_page, view };
 	}
 
@@ -667,7 +681,7 @@ public abstract class Supervisor extends HttpServlet {
 				holder.session_null = true;
 			}
 			else if ( !data.isSame( request ) ) {
-				session.invalidate();
+				clear_session( session );
 				session = null;
 				data = new SessionData( request );
 				holder.session_null = true;
@@ -691,7 +705,7 @@ public abstract class Supervisor extends HttpServlet {
 			return onErrorDebug( e, request, res, 422 );
 		}
 		req.setParam( method, request, this );
-		holder.search_engine = req.judgSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
+		holder.search_engine = req.judgeSearchEngine() != RequestParameter.SearchEngine.NO_SEARCHENGINE;
 		holder.request = req;
 
 		int	cnt = getRequestMaxCount();
