@@ -47,7 +47,7 @@ public class TransactionSequencer implements Serializable {
 	TransactionSequencer() {
 	}
 
-	private int newNo() {
+	private int newNo( PageID id ) {
 		long	dt = (new Date().getTime() / 1000) & 0x7fffff;
 		int		ret = (int)(dt << 8);
 		synchronized( this ) {
@@ -71,7 +71,7 @@ public class TransactionSequencer implements Serializable {
 			buf = buf.append( SALANE[0] );
 			buf = buf.append( "." );
 			buf = buf.append( HEAD[0] );
-			buf = buf.append( Integer.toString( seq.newNo(), Character.MAX_RADIX ) );
+			buf = buf.append( Integer.toString( seq.newNo( to ), Character.MAX_RADIX ) );
 			buf = buf.append( "." );
 		}
 		if ( from != null ) {
@@ -93,7 +93,7 @@ public class TransactionSequencer implements Serializable {
 		buf = buf.append( SALANE[0] );
 		buf = buf.append( "." );
 		buf = buf.append( HEAD[1] );
-		buf = buf.append( Integer.toString( seq.newNo(), Character.MAX_RADIX ) );
+		buf = buf.append( Integer.toString( seq.newNo( null ), Character.MAX_RADIX ) );
 		buf = buf.append( "." );
 		buf = buf.append( SALANE[2] );
 		buf = buf.append( "." );
@@ -159,7 +159,7 @@ public class TransactionSequencer implements Serializable {
 				Page	out = ret.to;
 				if ( out == null )	out = ret.redirect;
 				if ( out != null ) {
-					if ( out.isCheckRepeatSameRequest() && !request_id ) {
+					if ( seq != null && out.isCheckRepeatSameRequest() && !request_id ) {
 						return null;
 					}
 				}
