@@ -17,36 +17,58 @@ import paraselene.supervisor.*;
  * スレッドセーフです。
  */
 public class Tag extends HTMLPart {
-	private static final long serialVersionUID = 2L;
+	private static final Page	null_page = new NullPage(){
+		public Forward input( RequestParameter req, Forward fw ) throws PageException {return null;}
+	};
 	private String name;
 	protected HashMap<String,Attribute>	attr = new HashMap<String,Attribute>();
 	private ArrayList<HTMLPart>		doc = new ArrayList<HTMLPart>();
 	private ArrayList<Tag>		tag_only = new ArrayList<Tag>();
-	private Tag		parent = null;
 	private boolean nest_f = false;
 	private boolean visible_f = true;
+	private boolean dirty_f = true;
 
 	private static String	VALUE = "value";
 
+	private Page	embed_page = null_page;
+
+	/**
+	 * 所属先ページの取得。
+	 * @return 所属先。
+	 */
+	public Page getAssignedPage() {
+		if ( embed_page == null ) return null_page;
+		return embed_page;
+	}
+
+	/**
+	 * 更新された事を通知する。
+	 */
+	public void setModify() {
+		dirty_f = true;
+		if ( getAttribute( "id" ) == null ) {
+			getOuterTag().setModify();
+		}
+	}
+
 	/**
 	 * 外側のタグを返す。
 	 * @return 外側のタグ。自身が最外であるならnull。
 	 */
 	public Tag getOuterTag() {
-		return parent;
+		return getAssignedTag();
 	}
 
 	private synchronized Tag[] getOverUnder() {
 		Tag[]	ret = new Tag[]{ null, null };
-		if ( parent == null )	return ret;
-		int	cnt = parent.tag_only.size();
+		int	cnt = getAssignedTag().tag_only.size();
 		for ( int i = 0; i < cnt; i++ ) {
-			if ( parent.tag_only.get( i ) == this ) {
+			if ( getAssignedTag().tag_only.get( i ) == this ) {
 				if ( i > 0 ) {
-					ret[0] = parent.tag_only.get( i - 1 );
+					ret[0] = getAssignedTag().tag_only.get( i - 1 );
 				}
 				if ( i < cnt - 1 ) {
-					ret[1] = parent.tag_only.get( i + 1 );
+					ret[1] = getAssignedTag().tag_only.get( i + 1 );
 				}
 				break;
 			}
@@ -70,7 +92,9 @@ public class Tag extends HTMLPart {
 		return getOverUnder()[1];
 	}
 
-	protected Tag() {}
+	protected Tag() {
+		embed_page = null_page;
+	}
 
 	private static final String[]	plain_tag = new String[] {
 		"code",
@@ -119,6 +143,7 @@ public class Tag extends HTMLPart {
 	 * @param flag true:可視、false:不可視。
 	 */
 	public void setVisible( boolean flag ) {
+		setModify();
 		visible_f = flag;
 	}
 
@@ -144,6 +169,7 @@ public class Tag extends HTMLPart {
 	 * @param simple_f true:閉じタグ無し、false:閉じタグ有り。
 	 */
 	public Tag( String n, boolean simple_f ) {
+		this();
 		name = n.toLowerCase( Locale.ENGLISH );
 		nest_f = !simple_f;
 		if ( "body".equals( name ) )	makeID();
@@ -220,6 +246,7 @@ public class Tag extends HTMLPart {
 	 * @param at 属性。
 	 */
 	public void setAttribute( Attribute at ) {
+		setModify();
 		String	at_name = at.getName();
 		if ( "id".equals( at_name ) ) {
 			if ( getAttribute( "id" ) != null ) {
@@ -232,6 +259,7 @@ public class Tag extends HTMLPart {
 		synchronized( this ) {
 			attr.put( at.getName(), at );
 		}
+		at.setAssignedTag( this );
 		if ( "name".equals( at_name ) ) {
 			Tag	out = getOuterTag();
 			if ( out != null )	out.makeID();
@@ -253,6 +281,7 @@ public class Tag extends HTMLPart {
 	 * @param at_name 属性名。
 	 */
 	public synchronized void removeAttribute( String at_name ) {
+		setModify();
 		attr.remove( at_name.toLowerCase( Locale.ENGLISH ) );
 	}
 
@@ -279,12 +308,11 @@ public class Tag extends HTMLPart {
 	 * @param d 文書。
 	 */
 	public synchronized void addHTMLPart( int idx, HTMLPart d ) {
+		setModify();
 		doc.add( idx, d );
 		if ( d instanceof Tag ) {
 			Tag tag = (Tag)d;
-			if ( embed != null ) {
-				embed.nameTag( (Tag)d );
-			}
+			getAssignedPage().nameTag( tag );
 			int	cnt = doc.size();
 			idx = 0;
 			for ( int i = 0; i < cnt; i++ ) {
@@ -295,12 +323,9 @@ public class Tag extends HTMLPart {
 				}
 			}
 			tag_only.add( idx, tag );
-			tag.parent = this;
 			if ( tag.getAttribute( "name" ) != null )	makeID();
 		}
-		else {
-			d.setPage( this.embed );
-		}
+		d.setAssignedTag( this );
 	}
 
 	/**
@@ -382,17 +407,13 @@ public class Tag extends HTMLPart {
 	 */
 	public synchronized void removeHTMLPart( HTMLPart part ) {
 		if ( part == null )	return;
+		setModify();
 		if ( part instanceof Tag ) {
 			Tag	tag = (Tag)part;
 			tag_only.remove( tag );
-			tag.parent = null;
-			if ( embed != null ) {
-				embed.removeNameEntry( tag );
-			}
-		}
-		else {
-			part.setPage( null );
+			getAssignedPage().removeNameEntry( tag );
 		}
+		part.setAssignedTag( null );
 		doc.remove( part );
 	}
 
@@ -435,9 +456,7 @@ public class Tag extends HTMLPart {
 	 */
 	protected synchronized String getFirstTag() {
 		boolean	xml = false;
-		if ( embed != null ) {
-			xml = embed.isXML();
-		}
+		xml = getAssignedPage().isXML();
 		StringBuilder	buf = new StringBuilder( "<" );
 		buf = buf.append( getName() );
 		for ( String k : attr.keySet() ) {
@@ -525,6 +544,7 @@ public class Tag extends HTMLPart {
 	 * @param mode 文字列種別。
 	 */
 	public void write( PrintWriter w, StringMode mode ) {
+		dirty_f = false;
 		if ( !visible_f )	return;
 		w.print( getFirstTag() );
 		int	cnt = getHTMLPartCount();
@@ -776,12 +796,13 @@ public class Tag extends HTMLPart {
 		}
 	}
 
-	public synchronized void setPage( Page p ) {
-		super.setPage( p );
-		Attribute[]	attr = getAllAttribute();
-		for ( int i = 0; i < attr.length; i++ ) {
-			attr[i].setPage( p );
-		}
+	/**
+	 * 所属先ページ設定。
+	 * @param p 所属先。
+	 */
+	public void setAssignedPage( Page p ) {
+		if ( p == null )	p = null_page;
+		embed_page = p;
 	}
 }
 
