@@ -35,6 +35,10 @@ public class Form extends Tag {
 	 * 予約済みHIDDEN項目のname。paraselene$form
 	 */
 	public static final String FORM_ID = "paraselene$form";
+	/**
+	 * マルチパート。
+	 */
+	public static final String MULTI_PART = "multipart/form-data";
 
 	private static FormSeq	form_seq = new FormSeq();
 	private	String	seq;
@@ -172,7 +176,7 @@ public class Form extends Tag {
 		if ( val == null )	return;
 		if ( "file".equals( val ) ) {
 			try {
-				setAttribute( new Attribute( "enctype", "multipart/form-data" ) );
+				setAttribute( new Attribute( "enctype", MULTI_PART ) );
 			}
 			catch( Exception e ) {}
 			return;
