@@ -61,7 +61,7 @@ public class ColorMake {
 			bw.write( " * </tr>\n" );
 		}
 		bw.write( " * </table>\n */\n" );
-		bw.write( "public enum WebColor {\n" );
+		bw.write( "public enum WebColor implements Valuable {\n" );
 		int	size = color.size();
 		for ( int i = 0; i < size; i++ ) {
 			Color	bg = color.get( i );
